gchecky.model.checkout_redirect_t

Package gchecky :: Module model :: Class checkout_redirect_t |
[hide private]
[frames] | no frames]

# Class checkout_redirect_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    checkout_redirect_t

Try doctests: >>> a = checkout_redirect_t(serial_number='blabla12345', ... redirect_url='http://www.somewhere.com') >>> b = gxml.Document.fromxml(a.toxml()) >>> a == b True

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``checkout-redirect``'`` The document's unique xml tag name.
| serial_number = `ID:PATH(@serial-number):REQ`
| redirect_url = `Url:PATH(redirect-url):REQ`
| _fields = ``{``'``redirect_url``'``:` Url:PATH(redirect-url):REQ`,` `'``serial``...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'redirect_url': Url:PATH(redirect-url):REQ,
       'serial_number': ID:PATH(@serial-number):REQ}